@@ -18,8 +18,8 @@
 
 import collections
 import contextlib
-import time
 import json
+import time
 
 import requests
 import requests.exceptions as rexc
@@ -246,7 +246,7 @@ class ApicSession(object):
     """Manages a session with the APIC."""
 
     def __init__(self, hosts, usr, pwd, ssl):
-        protocol = ssl and 'https' or 'http'
+        protocol = 'https' if ssl else 'http'
         self.api_base = collections.deque(['%s://%s/api' % (protocol, host)
                                            for host in hosts])
         self.session = requests.Session()
@@ -396,6 +396,24 @@ class ApicSession(object):
         url = self._mo_url(mo, *params)
         return self._send(self.session.delete, url)
 
+    def GET(self, url, data=None):
+        return self._send(self.session.get, url, data=data)
+
+    def POST(self, url, data=None):
+        return self._send(self.session.post, url, data=data)
+
+    def DELETE(self, url, data=None):
+        return self._send(self.session.delete, url, data=data)
+
+    def delete_class(self, klass):
+        nodes = self.GET('/node/class/%s.json' % klass)
+        for node in nodes:
+            dn = node[klass]['attributes']['dn']
+            try:
+                self.DELETE('/node/mo/' + dn + '.json')
+            except Exception as e:
+                LOG.debug(e)
+
     # Session management
 
     def _save_cookie(self, request, response):
@@ -408,7 +426,7 @@ class ApicSession(object):
             except KeyError:
                 raise cexc.ApicResponseNoCookie(request=request)
             timeout = int(attributes['refreshTimeoutSeconds'])
-            LOG.debug(("APIC session will expire in %d seconds"), timeout)
+            LOG.debug("APIC session will expire in %d seconds", timeout)
             # Give ourselves a few seconds to refresh before timing out
             self.session_timeout = timeout - 5
             self.session_deadline = time.time() + self.session_timeout
